@@ -6,7 +6,7 @@ from nexus.tools import combine_nexuses
 __author__ = 'Simon Greenhill <simon@simon.net.nz>'
 __doc__ = """combine-nexus - python-nexus tools v%(version)s
 combines a series of nexuses into one nexus.
-""" % {'version': VERSION,}
+""" % {'version': VERSION, }
 
 
 if __name__ == '__main__':
@@ -14,13 +14,13 @@ if __name__ == '__main__':
     from optparse import OptionParser
     parser = OptionParser(usage="usage: %prog nex1.nex nex2.nex ... nexN.nex")
     options, nexuslist = parser.parse_args()
-    
+
     if len(nexuslist) <= 1:
-        print __doc__
+        print(__doc__)
         parser.print_help()
         sys.exit()
-    
+
     nexuslist = [NexusReader(n) for n in nexuslist]
     out = combine_nexuses(nexuslist)
     out.write_to_file('combined.nex', charblock=False, interleave=False)
-    print("Written to combined.nex")
\ No newline at end of file
+    print("Written to combined.nex")
